Here are some ways to get help with Documenteer:

- [Documentation](https://documenteer.lsst.io)
- [Ask a question in #dm-docs (for LSST staff)](https://lsstc.slack.com/archives/C2B6DQBAL)
- [Post a GitHub issue](https://github.com/lsst-sqre/documenteer/issues/new)
